﻿Imports System.Globalization
Imports System.Text.RegularExpressions
Imports System.Threading
Imports System.Windows.Markup

Class Application
    Public Shared ReadOnly Property StartUpPath As String = System.IO.Path.GetDirectoryName(System.Diagnostics.Process.GetCurrentProcess().MainModule.FileName)
    Public Shared ReadOnly Property DataPath As String = $"{StartUpPath}\Data"
    Public Shared ReadOnly Property BackUpDataPath As String = $"{StartUpPath}\Data\BackUp"
    Public Shared ReadOnly Property DataFile As String = $"{StartUpPath}\Data\Notes.cxml"
    Public Shared ReadOnly Property AttachmentPath As String = $"{DataPath}\Files"

    Private Sub Application_Startup(sender As Object, e As StartupEventArgs) Handles Me.Startup
        SetCultureProgramWide(New CultureInfo("de-DE"))
        CreateDirs()
        BackItUp()
    End Sub

    Private Sub SetCultureProgramWide(newCulture As CultureInfo)
        Dim currentCulture As CultureInfo = newCulture
        Thread.CurrentThread.CurrentCulture = currentCulture
        Thread.CurrentThread.CurrentUICulture = currentCulture
        CultureInfo.DefaultThreadCurrentCulture = currentCulture
        CultureInfo.DefaultThreadCurrentUICulture = currentCulture
        FrameworkElement.LanguageProperty.OverrideMetadata(GetType(FrameworkElement), New FrameworkPropertyMetadata(XmlLanguage.GetLanguage(CultureInfo.CurrentCulture.IetfLanguageTag)))
    End Sub

    Private Sub CreateDirs()
        If Not IO.Directory.Exists(DataPath) Then IO.Directory.CreateDirectory(DataPath)
        If Not IO.Directory.Exists(AttachmentPath) Then IO.Directory.CreateDirectory(AttachmentPath)
        If Not IO.Directory.Exists(BackUpDataPath) Then IO.Directory.CreateDirectory(BackUpDataPath)
        If Not IO.Directory.Exists($"{BackUpDataPath}\{TimeForFolders()}") Then IO.Directory.CreateDirectory($"{BackUpDataPath}\{TimeForFolders()}")
    End Sub


    Private Sub BackItUp()

        If IO.File.Exists(DataFile) AndAlso Not IO.File.Exists($"{BackUpDataPath}\{TimeForFolders()}\Notes.cxml") Then
            IO.File.Copy(DataFile, $"{BackUpDataPath}\{TimeForFolders()}\Notes.cxml")
        End If

    End Sub

    Private Function TimeForFolders() As String
        Return $"{Regex.Replace($"{DateTime.Now.ToShortDateString}", "\.", "-")}"
    End Function
End Class